@@ -2,5 +2,5 @@ from .views import verify
 from django.urls import path
 
 urlpatterns = [
-    path('<str:email>/<str:email_token>', verify)
+    path('<str:token>', verify)
 ]
